==> a10-octavia-1.2.0.tar.gz: a10-octavia-1.2.0/a10_octavia/tests/common/a10constants.py <==
#    Copyright 2020, A10 Networks
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.


MOCK_HM_ID = 'mock-hm-1'
MOCK_POOL_ID = 'mock-pool-1'
MOCK_MEMBER_ID = 'mock-member-1'
MOCK_LOAD_BALANCER_ID = 'mock-lb-1'
MOCK_LISTENER_ID = 'mock-listener-1'
MOCK_FLAVOR_ID = 'mock-flavor-1'
MOCK_FLAVOR_PROF_ID = 'mock-flavor-prof-1'
MOCK_AMPHORA_ID = 'amphora_id'
MOCK_COOKIE_NAME = 'mock-cookie-1'
MOCK_CERT_FILENAME = 'mock-cert-filename-1'
MOCK_CERT_CONTENT = 'mock-cert-content-1'
MOCK_KEY_FILENAME = 'mock-key-filename-1'
MOCK_KEY_CONTENT = 'mock-key-content-1'
MOCK_KEY_PASS = 'mock-key-pass-1'
MOCK_TEMPLATE_NAME = 'mock-template-name-1'
MOCK_CERT_ACTION = 'import'
MOCK_CERT_TYPE = 'pem'

MOCK_VRID_FLOATING_IP_1 = '10.10.10.8'
MOCK_VRID_FLOATING_IP_2 = '10.10.10.9'
MOCK_VRID_PARTIAL_FLOATING_IP = '45'
MOCK_VRID_FULL_FLOATING_IP = '10.10.10.45'
MOCK_SUBNET_CIDR = '10.10.10.0/24'
MOCK_SUBNET_ID = 'mock-subnet-1'
MOCK_VRRP_PORT_ID = 'mock-vrrp-port-id'
MOCK_PORT_ID = 'mock-port-id'

SERVICE_GROUP_CONF_SECTION = 'service_group'
LISTENER_CONF_SECTION = 'listener'
HARDWARE_THUNDER_CONF_SECTION = 'hardware_thunder'
A10_GLOBAL_OPTS = 'a10_global'
MOCK_PARENT_PROJECT_ID = 'parent_project_id_with_length_32'
MOCK_CHILD_PART = 'child_part'
MOCK_CHILD_PROJECT_ID = '_child_project_id_with_length_32'
MOCK_CHILD_PARTITION = '_child_project'
MOCK_PROJECT_ID = 'mock-project-id'

A10_GLOBAL_CONF_SECTION = 'a10_global'
A10_HARDWARE_THUNDER_CONF_SECTION = 'hardware_thunder'
A10_CONTROLLER_WORKER_CONF_SECTION = 'a10_controller_worker'
LISTENER_CONF_SECTION = 'listener'
SERVICE_GROUP_CONF_SECTION = 'service_group'
SERVER_CONF_SECTION = 'server'
VIRTUAL_SERVER_CONFIG_SECTION = 'slb'
HEALTH_MONITOR_SECTION = 'health_monitor'


A10_HOUSE_KEEPING = 'a10_house_keeping'

MOCK_SERVICE_GROUP_PROTOCOL = "HTTP"
MOCK_POOL_ID_2 = "mock-pool-2"
MOCK_SUBNET_ID_2 = "mock-subnet-2"

MOCK_L7POLICY_ID = "mock-l7-policy-1"
MOCK_L7RULE_ID = "mock-l7-rule-1"

MOCK_TLS_CERTIFICATE_ID = "mock_tls_certificate_id"
MOCK_TOPOLOGY_ACTIVE_STANDBY = "ACTIVE_STANDBY"

==> a10-octavia-2.1.0.tar.gz: a10-octavia-2.1.0/a10_octavia/tests/common/a10constants.py <==
#    Copyright 2020, A10 Networks
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

MOCK_VTHUNDER_ID = 'mock-vthunder-1'
MOCK_HM_ID = 'mock-hm-cd61-49ed-8508-f22a12d770c5'
MOCK_POOL_ID = 'mock-pool-1'
MOCK_MEMBER_ID = 'mock-member-1'
MOCK_LOAD_BALANCER_ID = 'mock-lb-1'
MOCK_LISTENER_ID = 'mock-listener-1'
MOCK_FLAVOR_ID = 'mock-flavor-1'
MOCK_FLAVOR_PROF_ID = 'mock-flavor-prof-1'
MOCK_AMPHORA_ID = 'amphora_id'
MOCK_COMPUTE_ID = 'mock-compute-id'
MOCK_COOKIE_NAME = 'mock-cookie-1'
MOCK_CERT_FILENAME = 'mock-cert-filename-1'
MOCK_CERT_CONTENT = 'mock-cert-content-1'
MOCK_KEY_FILENAME = 'mock-key-filename-1'
MOCK_KEY_CONTENT = 'mock-key-content-1'
MOCK_KEY_PASS = 'mock-key-pass-1'
MOCK_TEMPLATE_NAME = 'mock-template-name-1'
MOCK_CERT_ACTION = 'import'
MOCK_CERT_TYPE = 'pem'

MOCK_VRID_FLOATING_IP_1 = '10.10.10.8'
MOCK_VRID_FLOATING_IP_2 = '10.10.10.9'
MOCK_VRID_PARTIAL_FLOATING_IP = '45'
MOCK_VRID_FULL_FLOATING_IP = '10.10.10.45'
MOCK_SUBNET_CIDR = '10.10.10.0/24'
MOCK_SUBNET_ID = 'mock-subnet-1'
MOCK_NETWORK_ID = 'mock-network-1'
MOCK_VRRP_PORT_ID = 'mock-vrrp-port-id'
MOCK_PORT_ID = 'mock-port-id'
MOCK_SET_ID = 'mock-set-id'
MOCK_FLEXPOOL_TOKEN = '0XD34DB33F'

SERVICE_GROUP_CONF_SECTION = 'service_group'
LISTENER_CONF_SECTION = 'listener'
HARDWARE_THUNDER_CONF_SECTION = 'hardware_thunder'
A10_GLOBAL_OPTS = 'a10_global'
MOCK_PARENT_PROJECT_ID = 'parent_project_id_with_length_32'
MOCK_CHILD_PART = 'child_part'
MOCK_CHILD_PROJECT_ID = '_child_project_id_with_length_32'
MOCK_CHILD_PARTITION = '_child_project'
MOCK_PROJECT_ID = 'mock-project-id'

A10_GLOBAL_CONF_SECTION = 'a10_global'
A10_HARDWARE_THUNDER_CONF_SECTION = 'hardware_thunder'
A10_CONTROLLER_WORKER_CONF_SECTION = 'a10_controller_worker'
LISTENER_CONF_SECTION = 'listener'
SERVICE_GROUP_CONF_SECTION = 'service_group'
SERVER_CONF_SECTION = 'server'
VIRTUAL_SERVER_CONFIG_SECTION = 'slb'
HEALTH_MONITOR_SECTION = 'health_monitor'
GLM_LICENSE_CONFIG_SECTION = 'glm_license'


A10_HOUSE_KEEPING = 'a10_house_keeping'

MOCK_SERVICE_GROUP_PROTOCOL = "HTTP"
MOCK_POOL_ID_2 = "mock-pool-2"
MOCK_SUBNET_ID_2 = "mock-subnet-2"

MOCK_L7POLICY_ID = "mock-l7-policy-1"
MOCK_L7RULE_ID = "mock-l7-rule-1"

MOCK_TLS_CERTIFICATE_ID = "mock_tls_certificate_id"
MOCK_TOPOLOGY_ACTIVE_STANDBY = "ACTIVE_STANDBY"
MOCK_TOPOLOGY_ROLE_MASTER = 'MASTER'
MOCK_TOPOLOGY_ROLE_BACKUP = 'BACKUP'

MOCK_OCTAVIA_HEALTH_MANAGER_CONTROLLER = "octavia_health_manager_controller"
MOCK_OCTAVIA_HEALTH_MONITOR = 'octavia_health_monitor'
